<?php
/**
 * Manage the database of the ad group
 * Description: the type of value's index : id, name, kind, amount, notes, type, date, sort, numberdatas
 *
 * Version: 1.0.0
 *
 */
class Ad_Groups_Mgn {

	private $tb_nm; // The name of table.

	/**
	 * Contructor of this class.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @param	string	$tb_nm			The name of table
	 */
	function __construct() {
		global $wpdb;
		$this->tb_nm = $wpdb->prefix . "wpsite_takeover_ad_groups";
		$wpdb->query("
			CREATE TABLE IF NOT EXISTS `".$this->tb_nm."` (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`name` varchar(60) NOT NULL DEFAULT '',
				`notes` text,
				PRIMARY KEY (`id`)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;
		");
	}

	/**
	 * Get the list of data.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	array	$cond	description
	 * @return	mixed			The datas array on successful, false on failure.
	 */
	public function get_datas($cond = array()) {
		global $wpdb;
		$vals = array();

		$results = $wpdb->get_results($wpdb->prepare("SELECT id, name, notes FROM {$this->tb_nm} WHERE `name` LIKE %s", '%' . (isset($cond['name']) ? like_escape($cond['name']) : '') . '%'));

		if(!$results) {
			return false;
		}

		foreach ($results as $result) {
			$val = array();

			$val["id"]		= $result->id;
			$val["name"]	= stripcslashes($result->name);
			$val["notes"]	= stripcslashes($result->notes);
			$vals[] = $val;
		}

		return $vals;
	}

	/**
	 * Get the list of data.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	array	$cond	description
	 * @return	mixed			The datas array on successful, false on failure.
	 */
	public function get_data_byid($id) {
		global $wpdb;
		$results = $wpdb->get_results($wpdb->prepare("SELECT id, name, notes FROM {$this->tb_nm} WHERE `id`= %d", $id));

		if(!$results) return FALSE;

		$val = array();
		foreach ($results as $result) {
			$val["id"]		= $result->id;
			$val["name"]	= stripcslashes($result->name);
			$val["notes"]	= stripcslashes($result->notes);
		}
		return $val;

	}
	/**
	 * Add data.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	array	$val	description
	 * @return	mixed			The new inserted ID on successful, false on failure.
	 */
	public function add_data($val) {
		global $wpdb;
		if(!is_array($val) || $val['name'] == "")
			return FALSE;

		$name = addslashes($val['name']);
		$notes = addslashes($val['notes']);

		$result = $wpdb->query($wpdb->prepare("INSERT INTO {$this->tb_nm} (name, notes) VALUES (%s, %s)", $name, $notes));

		if(!$result) return FALSE;

		$val["adgroup_id"] = $wpdb->insert_id;
		return $val;
	}

	/**
	 * update datas.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	int		$id		description
	 * @param	array	$val	description
	 * @return	mix				The id on successful, false on failure.
	 */
	public function update_data($val) {
		global $wpdb;
		if(!is_array($val) || $val['id'] == "")
			return FALSE;

		$name = addslashes($val['name']);
		$notes = addslashes($val['notes']);

		$result = $wpdb->query($wpdb->prepare("UPDATE {$this->tb_nm} SET name = %s, notes = '%s' WHERE id = %d", $name, $notes, $val['id']));

		if (!isset($result)) return false;
	}

	/**
	 * Delete data by id.
	 *
	 * Description:
	 *
	 * @since 1.0.0
	 *
	 * @access	public
	 * @param	int		$id			description
	 * @param	bool	$file_fg	description
	 * @return	bool				true on successful, false on failure.
	 */
	public function delete_data($id) {
		global $wpdb;

		$result = $wpdb->query($wpdb->prepare("DELETE FROM {$this->tb_nm} WHERE id = %d;", $id));

		if (!$result) return false;
	}
}
?>